@@ -5,6 +5,13 @@
 # adds to the resulting syntax database, plus it tries to extract info
 # from the interpreter about things like subcommands.
 
+if 0 {
+    # Example how to pick up other information
+    lappend ::auto_path /usr/share/tcltk
+    catch {package require uuid}
+    set syntax(uuid::uuid) "s x*"
+}
+
 # Autoload stuff to have them available
 catch {parray} ; catch {tk_dialog} ; catch {package require msgcat}
 foreach gurkmeja [array names auto_index] {
@@ -548,21 +555,25 @@ proc buildDb {ch} {
         set syntax(oo::class)    "s x*"
         set syntax(oo::class\ create) "do=_stdclass_oo cn?"
         set syntax(oo::class\ create::constructor) dk ;# Define constructor
-        set syntax(oo::class\ create::superclass)  di ;# Define inheritance
+        set syntax(oo::class\ create::superclass)  "o? di" ;# Define inheritance
         set syntax(oo::class\ create::method) "dm"    ;# Define method 
         set syntax(oo::class\ create::destructor) dd  ;# Define destructor
-        set syntax(oo::class\ create::variable) div*
+        set syntax(oo::class\ create::variable) "o? div*"
         set syntax(oo::class\ create::export) x
         set syntax(oo::class\ create::class) x
         set syntax(oo::class\ create::deletemethod) "x x*"
         set syntax(oo::class\ create::export) "x x*"
         set syntax(oo::class\ create::filter) "o? x*"
         set syntax(oo::class\ create::forward) "x x x*"
-        set syntax(oo::class\ create::mixin) "o? x*"
+        set syntax(oo::class\ create::mixin) "o? di" ;# TBD, like inheritance?
         set syntax(oo::class\ create::renamemethod) "x x"
         set syntax(oo::class\ create::self) "x*"
         set syntax(oo::class\ create::unexport) "x x*"
 
+        foreach s {filter mixin superclass variable} {
+            set option(oo::class\ create::$s) "-append -clear -set"
+        }
+
         set syntax(_stdclass_oo) "s x*"
         set subCmd(_stdclass_oo) "create new destroy variable varname"
         set syntax(_stdclass_oo\ create) "dc=_obj,_stdclass_oo x?"
@@ -613,9 +624,14 @@ proc buildDb {ch} {
     # Things added in 8.7
     if {[info commands lpop] ne ""} {
         set syntax(lpop) "v x*"
+        set syntax(ledit) "v x x x*"
+        set syntax(lseq)  "x x*"
         set syntax(timerate) "o* c x? x?"
         set option(timerate\ -overhead) 1
 
+        set syntax(file\ home)        "x?"
+        set syntax(file\ tildeexpand) "x"
+
         set syntax(zipfs) "s x*"
         set syntax(zipfs\ canonical) "r 1 3"
         set syntax(zipfs\ exists)  1
